from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool
from django.utils.translation import ugettext_lazy as _

from models import Fb

class FacebookAlbumPlugin(CMSPluginBase):
    model = Fb
    name = _("Facebook Album")
    render_template = "cms_plugins/fb_album.html"

    def render(self, context, instance, placeholder):
        context.update({
          'object': instance,
          })
        return context

plugin_pool.register_plugin(FacebookAlbumPlugin)



from cms.models.pluginmodel import CMSPlugin
from django.utils.translation import ugettext_lazy as _
from django.db import models

class Fb(CMSPlugin):
  album_url = models.CharField(_('Album Url'), max_length=125)
  access_token = models.CharField('Access token', max_length=500)




from setuptools import setup, find_packages

version = '0.0.3'

setup(
    name = 'cmsplugin-fbalbum',
    version = version,
    description = 'facebook album plugin for django-cms',
    author = 'Vinit Kumar',
    author_email = 'vinit.kumar@changer.nl',
    url='http://github.com/vinitcool76/cmsplugin-fbalbum.git',
    packages = find_packages(),
    zip_safe=False,
    include_package_data = True,
    install_requires=[
        'Django>=1.2',
        'django-cms',
    ],
)
